#!/bin/sh
# Copyright 2009 Cloudera, inc.
set -ex

usage() {
  echo "
usage: $0 <options>
  Required not-so-options:
     --build-dir=DIR             path to oozie dist.dir
     --prefix=PREFIX             path to install into

  Optional options:
     --lib-dir=DIR               path to install oozie home [/usr/lib/oozie]
     --installed-lib-dir=DIR     path where lib-dir will end up on target system
     --bin-dir=DIR               path to install bins [/usr/bin]
     ... [ see source for more similar options ]
  "
  exit 1
}

OPTS=$(getopt \
  -n $0 \
  -o '' \
  -l 'prefix:' \
  -l 'lib-dir:' \
  -l 'installed-lib-dir:' \
  -l 'bin-dir:' \
  -l 'build-dir:' -- "$@")

if [ $? != 0 ] ; then
    usage
fi

eval set -- "$OPTS"
while true ; do
    case "$1" in
        --prefix)
        PREFIX=$2 ; shift 2
        ;;
        --build-dir)
        BUILD_DIR=$2 ; shift 2
        ;;
        --lib-dir)
        LIB_DIR=$2 ; shift 2
        ;;
        --installed-lib-dir)
        INSTALLED_LIB_DIR=$2 ; shift 2
        ;;
        --bin-dir)
        BIN_DIR=$2 ; shift 2
        ;;
        --)
        shift ; break
        ;;
        *)
        echo "Unknown option: $1"
        usage
        exit 1
        ;;
    esac
done

for var in PREFIX BUILD_DIR ; do
  if [ -z "$(eval "echo \$$var")" ]; then
    echo Missing param: $var
    usage
  fi
done

LIB_DIR=${LIB_DIR:-$PREFIX/usr/lib/oozie}
INSTALLED_LIB_DIR=${INSTALLED_LIB_DIR:-/usr/lib/oozie}
BIN_DIR=${BIN_DIR:-$PREFIX/usr/bin}
CONF_DIR=/etc/oozie
CONF_DIST_DIR=/etc/oozie/conf.dist

# First we'll move everything into lib
install -d -m 0755 $LIB_DIR
(
cd $BUILD_DIR
for file in *
do
  if [ "$file" != "debian" ] && [ "$file" != "patch-stamp" ] && [ "$file" != "src" ] && [ "$file" != "build-indep-stamp" ] && [ "$file" != "oozie-client.tar.gz" ] && [ "$file" != "conf" ] && [ "$file" != "wars" ] && [ "$file" != "README.txt" ] && [ "$file" != "installextjs.sh" ]; then
    cp -R ./$file $LIB_DIR
  fi
done
)

# Copy in the /usr/bin/oozie wrapper
install -d -m 0755 $BIN_DIR
cat > $BIN_DIR/oozie <<EOF
#!/bin/sh

exec $INSTALLED_LIB_DIR/bin/oozie "\$@"
EOF
chmod 755 $BIN_DIR/oozie

